# Published Opinions

Published Opinions of the appellate courts are opinions certified for publication or ordered published and may be cited or relied on by courts and parties.

- Official Reports Opinions (Searchable 1850-Present) are the searchable, citable, published opinions that reflect postfiling corrections. This no-fee service is provided by LexisNexis.

- Slip Opinions are as-filed versions of opinions. Slip opinions certified for publication do not reflect enhancement, editing and correction for the Official Reports.

Supreme Court slip opinions are posted immediately on filing at 10:00 a.m. on Mondays and Thursdays. Court of Appeal slip opinions are posted throughout the day as soon after filing as possible.

Use the list below to select the slip opinions certified for publication, or ordered published, that you want to view and click on the "view" button to activate your selection.

Date Posted | Docket #/ File Format | Description
--- | --- | ---
May 07 2012 | S076721 [PDF] [DOC] | P. v. Jones 5/7/12 SC Case Details
May 03 2012 | S185305 [PDF] [DOC] | P. v. Thomas 5/3/12 SC Case Details
Apr 30 2012 | S185827 [PDF] [DOC] | Kirby v. Immoos Fire etc. 4/30/12 SC Case Details
Apr 30 2012 | S189733 [PDF] [DOC] | P. v. Cornett 4/30/12 SC Case Details
Apr 26 2012 | S173860 [PDF] [DOC] | Dicon Fiberoptics v. Franchise Tax Bd. 4/26/12 SC Case Details
Apr 26 2012 | S097189 [PDF] [DOC] | P. v. Myles 4/26/12 SC Case Details
Apr 26 2012 | S090499 [PDF] [DOC] | P. v. Livingston 4/26/12 SC Case Details
Apr 23 2012 | S183961 [PDF] [DOC] | Maldonado v. Super. Ct. 4/23/12 SC Case Details
Apr 19 2012 | S178823 [PDF] [DOC] | P. v. Hernandez 4/19/12 SC Case Details
Apr 16 2012 | S033149 [PDF] [DOC] | P. v. Weaver 4/16/12 SC Case Details
Apr 12 2012 | S166350 [PDF] [DOC] | Brinker Restaurant Corp. v. Super. Ct. 4/12/12 SC Case Details
Mar 29 2012 | S171382 [PDF] [DOC] | Quarry v. Doe I 3/29/12 SC Case Details
Mar 19 2012 | S064733 [PDF] [DOC] | P. v. Abel 3/19/12 SC Case Details
Mar 14 2012 | S186661M [PDF] [DOC] | P. v. Cravens 3/14/12 SC Case Details
Mar 08 2012 | S191400 [PDF] [DOC] | P. v. Manzo 3/8/12 SC Case Details
Mar 08 2012 | S188982 [PDF] [DOC] | C.A. v. William S. Hart Union High School 3/8/12 SC Case Details
Mar 05 2012 | S181788 [PDF] [DOC] | In re Lucas 3/5/12 SC Case Details
Feb 23 2012 | S048337 [PDF] [DOC] | P. v. Thomas 2/23/12 SC Case Details
Feb 06 2012 | S080947 [PDF] [DOC] | P. v. Enraca 2/6/12 SC Case Details
Feb 06 2012 | S055652 [PDF] [DOC] | P. v. Fuiava 2/6/12 SC Case Details
Feb 02 2012 | S027094 [PDF] [DOC] | P. v. Elliott 2/2/12 SC Case Details
Feb 02 2012 | S093754 [PDF] [DOC] | P. v. Brents 2/2/12 SC Case Details
Jan 30 2012 | S188619 [PDF] [DOC] | P. v. Johnson 1/30/12 SC Case Details
Jan 30 2012 | S186661 [PDF] [DOC] | P. v. Cravens 1/30/12 SC Case Details
Jan 27 2012 | S198387 [PDF] [DOC] | Vandermost v. Bowen 1/27/12 SC Case Details